import * as dotenv from 'dotenv';
import {Friendship} from './Friendship.interface';

dotenv.config();

const mariadb = require('mariadb');
const prod_pool = mariadb.createPool({
    host: process.env.DB_HOST,
    user: process.env.DB_USER,
    password: process.env.DB_PASSWORD,
    database: process.env.PARTYPLANER_PROD_DATABASE,
    connectionLimit: 5
});
const dev_pool = mariadb.createPool({
    host: process.env.DB_HOST,
    user: process.env.DB_USER,
    password: process.env.DB_PASSWORD,
    database: process.env.PARTYPLANER_DEV_DATABASE,
    connectionLimit: 5
});

/**
 * Returns all friends of the given user
 * @param useDev If the dev or prod database should be used
 * @param userId The userId of the user to fetch the friends for
 * @return Friendship[] A list of friends
 */
export const getFriendshipData = async (useDev: boolean, userId: string): Promise<Friendship[]> => {
    let conn;
    try {
        if (useDev) {
            conn = await dev_pool.getConnection();
        } else {
            conn = await prod_pool.getConnection();
        }

        let rows = await conn.query('SELECT f.friendship_id, f.friend_id, u.first_name as friend_first_name, u.last_name as friend_last_name, u.username as friend_username FROM friendships f LEFT OUTER JOIN users u ON f.friend_id = u.user_id WHERE f.user_id = ?', userId);

        let friends: Friendship[] = [];

        for (let row of rows) {
            friends.push({
                friendshipId: row.friendship_id,
                friendId: row.friend_id,
                friendFirstName: row.friend_first_name,
                friendLastName: row.friend_last_name,
                friendUsername: row.friend_username
            });
        }

        return friends;
    } catch (err) {
        throw err;
    } finally {
        if (conn) {
            conn.end();
        }
    }
};
