/**
 * Required External Modules and Interfaces
 */
import express, {Request, Response} from 'express';
import * as UserService from './user.service';
import logger from '../../../middleware/logger';

/**
 * Router Definition
 */
export const userRouter = express.Router();

userRouter.get('/:isDevCall', async (req: Request, res: Response) => {
    try {
        let userId = (req.query.userId ?? '').toString();
        let sessionId = (req.query.sessionId ?? '').toString();
        let sessionKey = (req.query.sessionKey ?? '').toString();
        let useDev: boolean = (req.params.isDevCall ?? '') === 'dev'; // TBD

        if (userId === '' || sessionId === '' || sessionKey === '') {
            res.status(400).send({
                'status': 'WRONG_PARAMS',
                'message': 'Missing or wrong parameters'
            });
            return;
        }

        if (!await UserService.checkSession(useDev, userId, sessionId, sessionKey)) {
            res.status(403).send({
                'status': 'INVALID_SESSION',
                'message': 'The user or session could not be found or the session is invalid'
            });
            return;
        }

        let data = await UserService.getUserData(useDev, userId);

        res.status(200).send(data);
    } catch (e) {
        logger.error('Error handling a request: ' + e.message);
        res.status(500).send({'message': 'Internal Server Error. Try again later.'});
    }
});
